/**
 * Simple bug reproducing example.
 *
 * When using a long option with a hyphen in its name, the error string does
 * not output the option name, but rather the substring from the rightmost
 * hyphen position.
 *
 * Compile and start with option "foo-bar <nonumber>". <nonumber> shall not be
 * lexical_castable to double.
 *
 * The error message will be:
 *     "error: the argument ('nonumber') for option '--bar' is invalid"
 *                                                   ^^^^^
 *
 * The error message should be:
 *     "error: the argument ('nonumber') for option '--foo-bar' is invalid"
 *                                                  ^^^^^^^^^
 *
 * @author Markus Roth <markus.roth@herr-biber.de>
 */

#include <boost/program_options.hpp>
namespace po = boost::program_options;

#include <iostream>
using namespace std;

// Start me with option "--foo-bar nonumber"
int main(int ac, char* av[])
{
    try {
        po::options_description desc("Allowed options");
        desc.add_options()
            ("foo-bar", po::value<double>(), "an option with a hyphen in it's name")
        ;

        po::variables_map vm;
        po::store(po::parse_command_line(ac, av, desc), vm);
        po::notify(vm);
    }
    catch(exception& e) {
        cerr << "error: " << e.what() << "\n";
        return 1;
    }

    return 0;
}
